{ config, pkgs, lib, prefs, ... }:

{
  options.modules.nvidia.enable = lib.mkEnableOption "Enable NVIDIA kernel and modprobe configurations.";

  config = lib.mkIf config.modules.nvidia.enable {
    environment.systemPackages = with pkgs; [
      libva
      nvidia-vaapi-driver
    ];

    hardware.graphics = {
      enable = true;
      enable32Bit = true;
    };

    services.xserver.videoDrivers = [ "nvidia" ];
    boot.kernelParams = ["nvidia.NVreg_PreserveVideoMemoryAllocations=1"];

    hardware.nvidia = {
      modesetting.enable = true;
      powerManagement.finegrained = true;
      prime = {
        offload.enable = true;
        intelBusId = prefs.hosts.hulk.intelBusId;
        nvidiaBusId = prefs.hosts.hulk.nvidiaBusId;
      };

      package = config.boot.kernelPackages.nvidiaPackages.legacy_470;
    };
  };
}
